@@ -1,4 +1,5 @@
 import json
+import logging
 from datetime import date
 from typing import DefaultDict, Any
 
@@ -98,19 +99,25 @@ def preservation_status(result) -> (dict, str):
     )
     issn = result["ISSN"] if "ISSN" in result else None
     volume = result["volume"] if "volume" in result else None
-    doi = result["DOI"]
 
     # not in sampling framework (yet)
     no = None
 
-    return show_preservation(container_title, issn, volume, no, doi)
+    return show_preservation(
+        container_title=container_title,
+        issn=issn,
+        volume=volume,
+        no=no,
+        doi=result,
+    )
 
 
-def process_member_sample(samples, sample_path) -> dict:
+def process_member_sample(samples, sample_path, verbose=False) -> dict:
     """
     Processes samples for a single member
     :param samples: the samples to process
     :param sample_path: the path of the sample
+    :param verbose: whether or not to print the sample
     :return: a dictionary of preservation statistics
     """
     from constants import archives
@@ -132,6 +139,8 @@ def process_member_sample(samples, sample_path) -> dict:
     one_archive = 0
 
     for sample_item in samples:
+        overall_status["about"]["member"] = sample_item["member"]
+
         result = json.loads(sample_item)["data-point"]
 
         # we can only work with journal articles
@@ -170,6 +179,25 @@ def process_member_sample(samples, sample_path) -> dict:
                 if has_preservation:
                     overall_status["preserved-count"] += 1
 
+                    if verbose:
+                        logging.info(f"{doi['DOI']} has a preservation")
+                        logging.info(
+                            f"Running total: "
+                            f"{overall_status['preserved-count']} preserved, "
+                            f"{overall_status['unpreserved-count']} unpreserved"
+                        )
+
+                else:
+                    overall_status["unpreserved-count"] += 1
+
+                    if verbose:
+                        logging.info(f"{doi['DOI']} has no preservation")
+                        logging.info(
+                            f"Running total: "
+                            f"{overall_status['preserved-count']} preserved, "
+                            f"{overall_status['unpreserved-count']} unpreserved"
+                        )
+
                 # increment the correct counters for overall stats
                 if archive_count == 1:
                     one_archive += 1
@@ -247,6 +275,7 @@ def process_sample(
     samples_path,
     member_id,
     code_bucket,
+    verbose=False,
 ):
     """
     Process a single member sample
@@ -256,6 +285,7 @@ def process_sample(
     :param samples_bucket: the samples bucket
     :param samples_path: the samples path
     :param member_id: the member id
+    :param verbose: whether or not to print status messages
     :param code_bucket: the code bucket where settings are located
     :return:
     """
@@ -267,6 +297,10 @@ def process_sample(
     session = boto3.Session()
     s3 = session.resource("s3")
 
+    import environment
+
+    environment.setup_environment(code_bucket, download_settings=False)
+
     logging.info(f"Processing member {member_id}")
 
     samples = get_samples(
@@ -276,7 +310,9 @@ def process_sample(
         samples_path=samples_path,
     )
 
-    overall_status = process_member_sample(samples, samples_path)
+    overall_status = process_member_sample(
+        samples, samples_path, verbose=verbose
+    )
 
     push_json_to_s3(
         s3,
